@@ -133,10 +133,10 @@ CervisiaPart::CervisiaPart( TQWidget *parentWidget, const char *widgetName,
                                   : Qt::Horizontal;
         splitter = new TQSplitter(o, parentWidget, widgetName);
         // avoid PartManager's warning that Part's window can't handle focus
-        splitter->setFocusPolicy( TQ_StrongFocus );
+        splitter->setFocusPolicy( TQWidget::StrongFocus );
 
         update = new UpdateView(*config(), splitter);
-        update->setFocusPolicy( TQ_StrongFocus );
+        update->setFocusPolicy( TQWidget::StrongFocus );
         update->setFocus();
         connect( update, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
                  this, TQT_SLOT(popupRequested(TDEListView*, TQListViewItem*, const TQPoint&)) );
@@ -144,7 +144,7 @@ CervisiaPart::CervisiaPart( TQWidget *parentWidget, const char *widgetName,
                  this, TQT_SLOT(openFile(TQString)) );
 
         protocol = new ProtocolView(appId, splitter);
-        protocol->setFocusPolicy( TQ_StrongFocus );
+        protocol->setFocusPolicy( TQWidget::StrongFocus );
 
         setWidget(splitter);
     }
