@@ -122,7 +122,7 @@ KompareListView::KompareListView( bool isSource,
 	setFrameStyle( TQFrame::NoFrame );
 	setVScrollBarMode( TQScrollView::AlwaysOff );
 	setHScrollBarMode( TQScrollView::AlwaysOff );
-	setFocusPolicy( TQ_NoFocus );
+	setFocusPolicy( TQWidget::NoFocus );
 	setFont( m_settings->m_font );
 	setSpaces( m_settings->m_tabToNumberOfSpaces );
 	setFocusProxy( parent->parentWidget() );
