@@ -1469,7 +1469,7 @@ void TopLevel::setTraceItemDelayed(TraceItem* i)
   // no need to select same item a 2nd time...
   if (_traceItemDelayed == i) return;
   _traceItemDelayed = i;
-  _lastSender = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
+  _lastSender = sender();
 
   kdDebug() << "Selected " << (i ? i->prettyName() : "(none)") << endl;
 
