@@ -398,7 +398,7 @@ private:
  */
 class TreeMapWidget: public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
